# mihomo.py

## Introduction

This is a Python library for getting data from [mihomo.me](https://api.mihomo.me). It can also parse the data into a more readable format.

## Installation

```bash
pip install mihomo
```

## Usage

Refer to [example](./examples/example.py).

Document of API: <https://march7th.xiaohei.moe/en/resource/mihomo_api.html>
